Summary:	A tool for managing OCI containers and pods
Name:		podman
Version:	5.5.0
Release:	1
License:	Apache v2.0
Group:		Applications/System
#Source0Download: https://github.com/containers/podman/releases
Source0:	https://github.com/containers/podman/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	be4fa41859422f46256dbbc22a24c870
Source1:	policy.json
Source2:	registries.conf
URL:		https://github.com/containers/podman
BuildRequires:	btrfs-progs-devel
BuildRequires:	device-mapper-devel
BuildRequires:	go-md2man
BuildRequires:	golang >= 1.23.3
BuildRequires:	golang-varlink
BuildRequires:	gpgme-devel
BuildRequires:	libseccomp-devel
BuildRequires:	pkgconfig
BuildRequires:	python3-modules
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 2.009
BuildRequires:	systemd-devel
Requires:	conmon
Requires:	crun
Requires:	netavark
Suggests:	passt
Suggests:	uidmap
ExclusiveArch:	%go_arches
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_enable_debug_packages 0

%description
Podman (the POD MANager) is a tool for managing containers and images,
volumes mounted into those containers, and pods made from groups of
containers. Podman is based on libpod, a library for container
lifecycle management that is also contained in this repository. The
libpod library provides APIs for managing containers, pods, container
images, and volumes.

%package -n bash-completion-podman
Summary:	bash-completion for podman
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion >= 1:2.0
BuildArch:	noarch

%description -n bash-completion-podman
This package provides bash-completion for podman.

%package -n fish-completion-podman
Summary:	Fish completion for podman command
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	fish
BuildArch:	noarch

%description -n fish-completion-podman
Fish completion for podman command.

%package -n zsh-completion-podman
Summary:	Zsh completion for podman command
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	zsh
BuildArch:	noarch

%description -n zsh-completion-podman
Zsh completion for podman command.

%prep
%setup -q

%build
%{__make} -j1 \
	GO=/usr/bin/go \
	GOCMD="CGO_ENABLED=1 %__go" \
	GOPATH=$(pwd)/.gopath \
	PREFIX="%{_prefix}" \
	BINDIR="%{_bindir}" \
	LIBEXECDIR="%{_libexecdir}" \
	MANDIR="%{_mandir}" \
	SHAREDIR_CONTAINERS="%{_datadir}/containers" \
	ETCDIR="%{_sysconfdir}" \
	TMPFILESDIR="%{systemdtmpfilesdir}" \
	SYSTEMDDIR="%{systemdunitdir}" \
	USERSYSTEMDDIR="%{systemduserunitdir}" \
	PYTHON="%{__python3}"

%install
rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT{%{_sysconfdir}/containers,%{bash_compdir},%{fish_compdir},%{zsh_compdir},%{_sharedstatedir}/containers}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT \
	PREFIX="%{_prefix}" \
	BINDIR="%{_bindir}" \
	LIBEXECDIR="%{_libexecdir}" \
	MANDIR="%{_mandir}" \
	SHAREDIR_CONTAINERS="%{_datadir}/containers" \
	ETCDIR="%{_sysconfdir}" \
	TMPFILESDIR="%{systemdtmpfilesdir}" \
	SYSTEMDDIR="%{systemdunitdir}" \
	SYSTEMDGENERATORSDIR="%{_systemdgeneratordir}" \
	USERSYSTEMDGENERATORSDIR="%{_systemdusergeneratordir}" \
	USERSYSTEMDDIR="%{systemduserunitdir}" \
	PYTHON="%{__python3}"

cp -p %{SOURCE1} %{SOURCE2} \
	vendor/github.com/containers/common/pkg/config/containers.conf \
	$RPM_BUILD_ROOT%{_sysconfdir}/containers

%{__sed} -e 's|/var/lib/containers|%{_sharedstatedir}/containers|g' \
	vendor/github.com/containers/storage/storage.conf \
	> $RPM_BUILD_ROOT%{_sysconfdir}/containers/storage.conf

$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{bash_compdir}/podman bash
$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{fish_compdir}/podman.fish fish
$RPM_BUILD_ROOT%{_bindir}/podman completion -f $RPM_BUILD_ROOT%{zsh_compdir}/_podman zsh

%clean
rm -rf $RPM_BUILD_ROOT

%post
%systemd_post podman.service podman.socket

%preun
%systemd_preun podman.service podman.socket

%postun
%systemd_reload

%files
%defattr(644,root,root,755)
%doc README.md
%dir %{_sysconfdir}/containers
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/containers.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/policy.json
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/registries.conf
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/containers/storage.conf
%attr(755,root,root) %{_bindir}/podman
%attr(755,root,root) %{_bindir}/podman-remote
%attr(755,root,root) %{_bindir}/podmansh
%dir %{_libexecdir}/podman
%attr(755,root,root) %{_libexecdir}/podman/quadlet
%attr(755,root,root) %{_libexecdir}/podman/rootlessport
%{systemdunitdir}/podman.service
%{systemdunitdir}/podman.socket
%{systemdunitdir}/podman-auto-update.service
%{systemdunitdir}/podman-auto-update.timer
%{systemdunitdir}/podman-clean-transient.service
%{systemdunitdir}/podman-kube@.service
%{systemdunitdir}/podman-restart.service
%{_systemdgeneratordir}/podman-system-generator
%{systemduserunitdir}/podman.service
%{systemduserunitdir}/podman.socket
%{systemduserunitdir}/podman-auto-update.service
%{systemduserunitdir}/podman-auto-update.timer
%{systemduserunitdir}/podman-clean-transient.service
%{systemduserunitdir}/podman-kube@.service
%{systemduserunitdir}/podman-restart.service
%{systemduserunitdir}/podman-user-wait-network-online.service
%{_systemdusergeneratordir}/podman-user-generator
%{_mandir}/man1/podman*.1*
%{_mandir}/man5/podman-systemd.unit.5*
%{_mandir}/man5/quadlet.5*
%{_mandir}/man7/podman-rootless.7*
%{_mandir}/man7/podman-troubleshooting.7*
/usr/lib/tmpfiles.d/podman.conf
%dir %{_sharedstatedir}/containers

%files -n bash-completion-podman
%defattr(644,root,root,755)
%{bash_compdir}/podman

%files -n fish-completion-%{name}
%defattr(644,root,root,755)
%{fish_compdir}/podman.fish

%files -n zsh-completion-%{name}
%defattr(644,root,root,755)
%{zsh_compdir}/_podman
%changelog
* Sun May 18 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/podman.git;a=log;h=master

* Wed May 14 2025 Jan Palus <atler@pld-linux.org> f949998
- up to 5.5.0

* Tue Mar 11 2025 Jan Palus <atler@pld-linux.org> 0409097
- up to 5.4.1

* Tue Feb 11 2025 Jan Palus <atler@pld-linux.org> a02485f
- up to 5.4.0

* Thu Jan 23 2025 Jan Palus <atler@pld-linux.org> d918a02
- up to 5.3.2 (fixes CVE-2024-11218)

* Wed Nov 13 2024 Jan Palus <atler@pld-linux.org> ebce3a6
- up to 5.3.0

* Wed Oct 23 2024 Jan Palus <atler@pld-linux.org> 545d49b
- up to 5.2.5 (fixes CVE-2024-9675 CVE-2024-9676)

* Mon Oct 07 2024 Jan Palus <atler@pld-linux.org> 5920dad
- up to 5.2.4 (fixes CVE-2024-9407 CVE-2024-9341)

* Tue Sep 24 2024 Jan Palus <atler@pld-linux.org> 1f17936
- up to 5.2.3

* Wed Aug 21 2024 Jan Palus <atler@pld-linux.org> b8fc2c4
- up to 5.2.2

* Thu Aug 15 2024 Jan Palus <atler@pld-linux.org> 53d4af8
- up to 5.2.1

* Fri Aug 02 2024 Jan Palus <atler@pld-linux.org> 8997835
- up to 5.2.0

* Wed Jul 10 2024 Jan Palus <atler@pld-linux.org> 75274d8
- up to 5.1.2

* Thu May 30 2024 Jan Palus <atler@pld-linux.org> 9b37bdf
- up to 5.1.0

* Fri May 10 2024 Jan Palus <atler@pld-linux.org> b91c1b5
- up to 5.0.3 (fixes CVE-2024-3727)

* Wed Apr 17 2024 Jan Palus <atler@pld-linux.org> bda82e1
- up to 5.0.2

* Tue Apr 02 2024 Jan Palus <atler@pld-linux.org> 7a82f34
- up to 5.0.1

* Wed Mar 20 2024 Jan Palus <atler@pld-linux.org> cc7757f
- up to 5.0.0

* Wed Feb 14 2024 Jan Palus <atler@pld-linux.org> 3918311
- up to 4.9.3

* Sat Feb 03 2024 Jan Palus <atler@pld-linux.org> 57d343f
- up to 4.9.2

* Thu Feb 01 2024 Jan Palus <atler@pld-linux.org> c5d0e85
- up to 4.9.1

